@@ -13,7 +13,4 @@ class SimpleHTMLPosting(AbstractPosting, ABC):
         super().__init__(session, url, post_id, title, author, html)
 
     def accept(self, visitor: PostingVisitor) -> None:
-        visitor.visit_author_name(self._html_content)
         visitor.visit_content(self._html_content)
-        visitor.visit_file(self._html_content)
-        visitor.visit_comment(self._html_content)
